/*
 * @(#) Coordinator.java
 *
 * JOTM: Java Open Transaction Manager 
 *
 * This project is developed inside the ObjectWeb Consortium,
 * http://www.objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Coordinator.java,v 1.4 2003/04/17 14:19:44 jmesnil Exp $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jotm;

import java.rmi.Remote;
import java.rmi.RemoteException;

/**
 * OTS-like Coordinator.
 * 
 * @see <a href="http://java.sun.com/products/jts/javadoc/org/omg/CosTransactions/Coordinator.html">OTS Coordinator</a>
 * @author jmesnil
 */
public interface Coordinator extends Remote {
    
    /**
     * @return status
     * @throws RemoteException if a remote exception occurs
     */
    public int get_status() throws RemoteException;
    
    /**
     * @param tc Coordinator
     * @return <code>true</code> if transaction is the same than for 
     * <code>tc</code>
     * @throws RemoteException if a remote exception occurs
     */
    public boolean is_same_transaction(Coordinator tc) throws RemoteException;
    
    /**
     * @param r Resource
     * @return RecoveryCoordinator
     * @throws RemoteException if a remote exception occurs
     */
    public RecoveryCoordinator register_resource(Resource r)
        throws RemoteException;
    
    /**
     * @param sync RemoteSynnchro
     * @throws RemoteException if a remote exception occurs
     */
    public void register_synchronization(RemoteSynchro sync)
        throws RemoteException;
    
    /**
     * @throws RemoteException if a remote exception occurs
     */
    public void rollback_only() throws RemoteException;
    
    /**
     * @return transaction name
     * @throws RemoteException if a remote exception occurs
     */
    public String get_transaction_name() throws RemoteException;
}
